Change Log
----------

2.1.0
~~~~~
Added pagination support.
Added subfields support.
Added create new resource function.
Update function now works correctly.
Better unicode conversion for border case data.

2.0.0
~~~~~
Rewritten from scratch version with basic update support and
multiple formats(csv, console) support.

1.0.0
~~~~~
Initial version
